jobject java_lang_reflect_Constructor_constructNative(JNIEnv* env, jobject clazz, jobjectArray args,jclass theclass, jint slot);
jint java_lang_reflect_Constructor_getModifiers(JNIEnv* env, jclass clazz);
